@@ -1,6 +1,6 @@
 use strict;
 package Web::Authenticate;
-$Web::Authenticate::VERSION = '0.005';
+$Web::Authenticate::VERSION = '0.009';
 use Mouse;
 use Carp;
 use Web::Authenticate::Cookie::Handler;
@@ -9,6 +9,7 @@ use Web::Authenticate::Result::CreateUser;
 use Web::Authenticate::Result::Login;
 use Web::Authenticate::Result::Authenticate;
 use Web::Authenticate::Result::IsAuthenticated;
+use Web::Authenticate::Result::CheckForSession;
 use Web::Authenticate::RequestUrlProvider::CgiRequestUrlProvider;
 use Ref::Util qw/is_arrayref/;
 #ABSTRACT: Allows web authentication using cookies and a storage engine. 
@@ -106,6 +107,14 @@ has allow_after_login_redirect_time_seconds => (
     default => 300,
 );
 
+
+has allow_multiple_sessions_per_user => (
+    isa => 'Bool',
+    is => 'ro',
+    required => 1,
+    default => undef,
+);
+
 has _after_login_redirect_override_cookie_name => (
     isa => 'Str',
     is => 'ro',
@@ -134,7 +143,11 @@ sub login {
             unless $authenticator->authenticate($user);
     }
     
-    $self->session_handler->invalidate_user_sessions($user);
+    $self->session_handler->invalidate_current_session;
+
+    unless ($self->allow_multiple_sessions_per_user) {
+        $self->session_handler->invalidate_user_sessions($user);
+    }
     $self->session_handler->create_session($user);
 
     my $redirect_url = $self->after_login_url;
@@ -241,6 +254,36 @@ sub is_authenticated {
 }
 
 
+sub check_for_session {
+    my $self = shift;
+    my %params = @_;
+
+    my $result = $self->is_authenticated;
+
+    return Web::Authenticate::Result::CheckForSession->new(success => undef) unless $result->success;
+
+    my $user = $result->user;
+    my $redirect_url;
+    my $result_auth_redirect;
+    if ($params{auth_redirects}) {
+        for my $auth_redirect (@{$params{auth_redirects}}) {
+            if ($auth_redirect->authenticator->authenticate($user)) {
+                $redirect_url = $auth_redirect->url;
+                $result_auth_redirect = $auth_redirect;
+                last;
+            }
+        }
+    }
+
+    unless ($redirect_url) {
+        $redirect_url = $self->after_login_url;
+    }
+
+    $self->redirect_handler->redirect($redirect_url);
+    return Web::Authenticate::Result::CheckForSession->new(success => 1, user => $user, auth_redir => $result_auth_redirect);
+}
+
+
 sub create_user {
     my ($self) = shift;
     my %params = @_;
@@ -304,7 +347,7 @@ Web::Authenticate - Allows web authentication using cookies and a storage engine
 
 =head1 VERSION
 
-version 0.005
+version 0.009
 
 =head1 SYNOPSIS
 
@@ -445,6 +488,11 @@ the user will be redirected to that url after a successful login. If set to fals
 The url of the page the user tried to load is set to a cookie if they are redirected to login from L</authenticate>. This sets the amount of time (in seconds)
 for the cookie to be valid. Default is 5 minutes.
 
+=head2 allow_multiple_sessions_per_user
+
+A bool (1 or undef) whether or not to allow multiple sessions per user. If set to true, when L<Web::Authenticate::Session::Handler::Role/invalidate_user_sessions> will
+not be called. Default is false.
+
 =head2 login
 
 =over
@@ -562,6 +610,27 @@ This method returns a L<Web::Authenticate::Result::IsAuthenticated> object.
 
 This method does not update the expires time for the session. It does however respect L</allow_after_login_redirect_override>.
 
+=head2 check_for_session 
+
+=over
+
+=item
+
+B<auth_redirects (optional)> - An arrayref of L<Web::Authenticate::Authenticator::Redirect::Role>. If the user is authenticated successfully with a session, they will 
+be redirected to the L<Web::Authenticate::Authenticator::Redirect::Role/url> of the first L<Web::Authenticate::Authenticator::Redirect::Role/authenticator>
+that authenticates. If none of the auth_redirects authenticate, then the user will be redirected to L</after_login_url>.
+
+=back
+
+This is meant to be used on the login page if you do not want users to be able to login if they are already authenticated.
+
+    $web_authenticate->check_for_session;
+
+    # or with auth redirects
+    $web_authenticate->check_for_session(auth_redirects => $auth_redirects);
+
+Returns L<Web::Authenticate::Result::CheckForSession>.
+
 =head2 create_user
 
 =over
