@@ -1,6 +1,6 @@
 use strict;
 package Web::Authenticate::Result::IsAuthenticated;
-$Web::Authenticate::Result::IsAuthenticated::VERSION = '0.008';
+$Web::Authenticate::Result::IsAuthenticated::VERSION = '0.009';
 use Mouse;
 #ABSTRACT: The result of calling Web::Authenticate::is_authenticated.
 
@@ -9,6 +9,7 @@ has success => (
     isa => 'Bool',
     is => 'ro',
     required => 1,
+    default => undef,
 );
 
 
@@ -23,6 +24,24 @@ has failed_authenticator => (
     is => 'ro',
 );
 
+# remove undef arguments before constructed
+around 'BUILDARGS' => sub {
+  my($orig, $self, @params) = @_;
+  my $params;
+
+  if(@params == 1 ) {
+    ($params) = @params;
+  } else {
+    $params = { @params };
+  }
+
+  for my $key (keys %$params){
+    delete $params->{$key} unless defined $params->{$key};
+  }
+
+  $self->$orig($params);
+};
+
 1;
 
 __END__
@@ -37,7 +56,7 @@ Web::Authenticate::Result::IsAuthenticated - The result of calling Web::Authenti
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 METHODS
 
